@@ -61,14 +61,21 @@ bool StatusLinux::UpdateStatus()
     return false;
   }
 
-  if (std::getline(file,line) && std::getline(file,line) && std::getline(file,line)) {
-    std::string::size_type start,end;
+  if (std::getline(file,line) && std::getline(file,line)) {
+    while (std::getline(file,line)) {
+      std::string::size_type start,end;
+      std::string            entry;
 
-    start=line.find_first_not_of(" ");
-    end=line.find(":");
+      start=line.find_first_not_of(" ");
+      end=line.find(":");
 
-    if (start!=std::string::npos && end!=std::string::npos) {
-      interface=line.substr(start,end-start);
+      if (start!=std::string::npos && end!=std::string::npos) {
+        entry=line.substr(start,end-start);
+
+        if (GetDefaultInterface().empty() || entry==GetDefaultInterface()) {
+          interface=entry;
+        }
+      }
     }
   }
 
@@ -86,6 +93,8 @@ bool StatusLinux::UpdateStatus()
     return false;
   }
 
+  std::cout << "Reading interface '" << interface << "'..." << std::endl;
+
   strcpy(ifr.ifr_name,interface.c_str());
 
   if (ioctl(handle,SIOCGIFADDR,&ifr)>=0) {
